#!/usr/bin/env python3
#
# Given two foci of an ellipsis, output its bounding box.
#
# Math is hard so we best try to avoid it by searching instead.
#

from math import isclose

x1, y1, x2, y2, a = map(int, input().split())
p1 = complex(x1, y1)
p2 = complex(x2, y2)
vmax = 1000

def distance(p):
    return abs(p - p1) + abs(p - p2)

#
# Canned binary search
#
def binary_search(f, l, r, y):
    while not isclose(l, r):
        m = (l + r)/2.0
        if f(m) < y:
            r = m
        else:
            l = m
    return m

#
# Canned ternary search
#
def ternary_search(f, l, r):
    while not isclose(l, r):
        m1 = (2*l + r)/3.0
        m2 = (l + 2*r)/3.0
        if f(m1) < f(m2):
            r = m2
        else:
            l = m1
    return (l+r)/2.0

def min_distance_for_x(x):
    def d2(y):
        return distance(complex(x, y))

    return d2(ternary_search(d2, -vmax, vmax))

def min_distance_for_y(y):
    def d2(x):
        return distance(complex(x, y))

    return d2(ternary_search(d2, -vmax, vmax))

xlow = binary_search(min_distance_for_x, -vmax, (x1+x2)/2, a)
xhigh = binary_search(lambda x : -min_distance_for_x(x), (x1+x2)/2, vmax, -a)
ylow = binary_search(min_distance_for_y, -vmax, (y1+y2)/2, a)
yhigh = binary_search(lambda y : -min_distance_for_y(y), (y1+y2)/2, vmax, -a)

print (xlow, ylow, xhigh, yhigh)
